=======
Drapery
=======

Drapery is a Python library and CLI tool to convert 2D geometries to 3D given an elevation source.

.. image:: https://travis-ci.org/mrahnis/drapery.svg?branch=master
    :target: https://travis-ci.org/mrahnis/drapery

.. image:: https://ci.appveyor.com/api/projects/status/github/mrahnis/drapery?svg=true
	:target: https://ci.appveyor.com/api/projects/status/github/mrahnis/drapery?svg=true

.. image:: https://readthedocs.org/projects/drapery/badge/?version=latest
	:target: http://drapery.readthedocs.io/en/latest/?badge=latest
	:alt: Documentation Status

Dependencies
============

drapery 0.0.2 depends on:

* `Python 3.x`_
* Click_
* Shapely_
* rasterio_
* fiona_

Installation
============

To install from the Python Package Index:

	$pip install drapery

To install from the source distribution execute the setup script in the drapery directory:

	$python setup.py install

Examples
========

To do

License
=======

BSD

Documentation
=============

Latest `html`_

.. _`Python 3.x`: http://www.python.org
.. _Click: http://click.pocoo.org
.. _Shapely: https://github.com/Toblerity/Shapely
.. _rasterio: https://github.com/mapbox/rasterio
.. _fiona: https://github.com/Toblerity/Fiona

.. _html: http://drapery.readthedocs.org/en/latest/